@@ -18,16 +18,14 @@ my $oDevice = Net::Frame::Device->new(target => $target);
 my $ip = Net::Frame::IPv4->new(
    src      => $oDevice->ip,
    dst      => $target,
-   protocol => NF_IPv4_PROTOCOL_ICMPv4,
-);
-my $icmp = Net::Frame::ICMPv4->new(
-   icmpType => Net::Frame::ICMPv4::Echo->new(payload => 'test'),
+   protocol => NP_IPv4_PROTOCOL_ICMPv4,
 );
+my $ihdr = Net::Frame::ICMPv4->new;
+my $icmp = Net::Frame::ICMPv4::Echo->new(payload => 'test');
 
 my $oSimple = Net::Frame::Simple->new(
-   layers => [ $ip, $icmp, ],
+   layers => [ $ip, $ihdr, $icmp, ],
 );
-print $oSimple->print."\n";
 
 my $oDump = Net::Frame::Dump::Online->new(dev => $oDevice->dev);
 $oDump->start;
