@@ -1,5 +1,5 @@
 #
-# $Id: AddressMask.pm,v 1.2 2006/11/30 22:32:39 gomor Exp $
+# $Id: AddressMask.pm,v 1.4 2006/12/05 21:11:44 gomor Exp $
 #
 package Net::Frame::ICMPv4::AddressMask;
 use strict;
@@ -16,7 +16,6 @@ our @AS = qw(
    identifier
    sequenceNumber
    addressMask
-   data
 );
 __PACKAGE__->cgBuildIndices;
 __PACKAGE__->cgBuildAccessorsScalar(\@AS);
@@ -31,27 +30,21 @@ sub new {
       identifier     => getRandom16bitsInt(),
       sequenceNumber => getRandom16bitsInt(),
       addressMask    => '0.0.0.0',
-      data           => '',
+      payload        => '',
       @_,
    );
 }
 
-sub getKey        { 'ICMP' }
-sub getKeyReverse { 'ICMP' }
+sub getPayloadLength { shift->SUPER::getPayloadLength }
 
-sub getDataLength {
-   my $self = shift;
-   ($self->data && length($self->data)) || 0;
-}
-
-sub getLength { 8 + shift->getDataLength }
+sub getLength { 8 + shift->getPayloadLength }
 
 sub pack {
    my $self = shift;
 
    $self->raw($self->SUPER::pack('nna4 a*',
       $self->identifier, $self->sequenceNumber, inetAton($self->addressMask),
-      $self->data,
+      $self->payload,
    )) or return undef;
 
    $self->raw;
@@ -60,14 +53,14 @@ sub pack {
 sub unpack {
    my $self = shift;
 
-   my ($identifier, $sequenceNumber, $addressMask, $data) =
+   my ($identifier, $sequenceNumber, $addressMask, $payload) =
       $self->SUPER::unpack('nna4 a*', $self->raw)
          or return undef;
 
    $self->identifier($identifier);
    $self->sequenceNumber($sequenceNumber);
    $self->addressMask(inetNtoa($addressMask));
-   $self->data($data);
+   $self->payload($payload);
 
    $self;
 }
@@ -78,29 +71,17 @@ sub print {
    my $self = shift;
 
    my $l = $self->layer;
-   my $buf = sprintf "$l: identifier:%d  sequenceNumber:%d  addressMask:%s",
+   sprintf "$l: identifier:%d  sequenceNumber:%d  addressMask:%s",
       $self->identifier, $self->sequenceNumber, $self->addressMask;
-
-   if ($self->data) {
-      $buf .= sprintf("\n$l: dataLength:%d  data:%s",
-         $self->getDataLength, $self->SUPER::unpack('H*', $self->data))
-            or return undef;
-   }
-
-   $buf;
 }
 
-#
-# Helpers
-#
-
 1;
 
 __END__
 
 =head1 NAME
 
-Net::Frame::ICMPv4 - Internet Control Message Protocol v4 layer object
+Net::Frame::ICMPv4::AddressMask - ICMPv4 AddressMask type object
 
 =head1 SYNOPSIS
 
@@ -341,13 +322,9 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2004-2006, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2006, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
 
-=head1 RELATED MODULES
-
-L<NetPacket>, L<Net::RawIP>, L<Net::RawSock>
-
 =cut
