@@ -1,5 +1,5 @@
 #
-# $Id: Information.pm,v 1.2 2006/11/30 22:32:39 gomor Exp $
+# $Id: Information.pm,v 1.4 2006/12/05 21:11:44 gomor Exp $
 #
 package Net::Frame::ICMPv4::Information;
 use strict;
@@ -15,7 +15,6 @@ our @EXPORT_OK   = ( @{$EXPORT_TAGS{consts}} );
 our @AS = qw(
    identifier
    sequenceNumber
-   data
 );
 __PACKAGE__->cgBuildIndices;
 __PACKAGE__->cgBuildAccessorsScalar(\@AS);
@@ -29,26 +28,20 @@ sub new {
    shift->SUPER::new(
       identifier     => getRandom16bitsInt(),
       sequenceNumber => getRandom16bitsInt(),
-      data           => '',
+      payload        => '',
       @_,
    );
 }
 
-sub getKey        { 'ICMP' }
-sub getKeyReverse { 'ICMP' }
+sub getPayloadLength { shift->SUPER::getPayloadLength }
 
-sub getDataLength {
-   my $self = shift;
-   ($self->data && length($self->data)) || 0;
-}
-
-sub getLength { 4 + shift->getDataLength }
+sub getLength { 4 + shift->getPayloadLength }
 
 sub pack {
    my $self = shift;
 
    $self->raw($self->SUPER::pack('nn a*',
-      $self->identifier, $self->sequenceNumber, $self->data,
+      $self->identifier, $self->sequenceNumber, $self->payload,
    )) or return undef;
 
    $self->raw;
@@ -57,13 +50,13 @@ sub pack {
 sub unpack {
    my $self = shift;
 
-   my ($identifier, $sequenceNumber, $data) =
+   my ($identifier, $sequenceNumber, $payload) =
       $self->SUPER::unpack('nn a*', $self->raw)
          or return undef;
 
    $self->identifier($identifier);
    $self->sequenceNumber($sequenceNumber);
-   $self->data($data);
+   $self->payload($payload);
 
    $self;
 }
@@ -74,29 +67,17 @@ sub print {
    my $self = shift;
 
    my $l = $self->layer;
-   my $buf = sprintf "$l: identifier:%d  sequenceNumber:%d",
+   sprintf "$l: identifier:%d  sequenceNumber:%d",
       $self->identifier, $self->sequenceNumber;
-
-   if ($self->data) {
-      $buf .= sprintf("\n$l: dataLength:%d  data:%s",
-         $self->getDataLength, $self->SUPER::unpack('H*', $self->data))
-            or return undef;
-   }
-
-   $buf;
 }
 
-#
-# Helpers
-#
-
 1;
 
 __END__
 
 =head1 NAME
 
-Net::Frame::ICMPv4 - Internet Control Message Protocol v4 layer object
+Net::Frame::ICMPv4::Information - ICMPv4 Information type object
 
 =head1 SYNOPSIS
 
@@ -337,13 +318,9 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2004-2006, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2006, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
 
-=head1 RELATED MODULES
-
-L<NetPacket>, L<Net::RawIP>, L<Net::RawSock>
-
 =cut
