@@ -1,5 +1,5 @@
 #
-# $Id: TimeExceed.pm,v 1.2 2006/11/30 22:32:39 gomor Exp $
+# $Id: TimeExceed.pm,v 1.4 2006/12/05 21:11:44 gomor Exp $
 #
 package Net::Frame::ICMPv4::TimeExceed;
 use strict;
@@ -14,7 +14,6 @@ our @EXPORT_OK   = ( @{$EXPORT_TAGS{consts}} );
 
 our @AS = qw(
    unused
-   data
 );
 __PACKAGE__->cgBuildIndices;
 __PACKAGE__->cgBuildAccessorsScalar(\@AS);
@@ -25,26 +24,20 @@ use Carp;
 
 sub new {
    shift->SUPER::new(
-      unused => 0,
-      data   => '',
+      unused  => 0,
+      payload => '',
       @_,
    );
 }
 
-sub getKey        { 'ICMP' }
-sub getKeyReverse { 'ICMP' }
+sub getPayloadLength { shift->SUPER::getPayloadLength }
 
-sub getDataLength {
-   my $self = shift;
-   ($self->data && length($self->data)) || 0;
-}
-
-sub getLength { 4 + shift->getDataLength }
+sub getLength { 4 + shift->getPayloadLength }
 
 sub pack {
    my $self = shift;
 
-   $self->raw($self->SUPER::pack('N a*', $self->unused, $self->data))
+   $self->raw($self->SUPER::pack('N a*', $self->unused, $self->payload))
       or return undef;
 
    $self->raw;
@@ -53,11 +46,11 @@ sub pack {
 sub unpack {
    my $self = shift;
 
-   my ($unused, $data) = $self->SUPER::unpack('N a*', $self->raw)
+   my ($unused, $payload) = $self->SUPER::unpack('N a*', $self->raw)
       or return undef;
 
    $self->unused($unused);
-   $self->payload($data);
+   $self->payload($payload);
 
    $self;
 }
@@ -68,28 +61,16 @@ sub print {
    my $self = shift;
 
    my $l = $self->layer;
-   my $buf = sprintf "$l: unused:%d", $self->unused;
-
-   if ($self->data) {
-      $buf .= sprintf("\n$l: dataLength:%d  data:%s",
-         $self->getDataLength, $self->SUPER::unpack('H*', $self->data))
-            or return undef;
-   }
-
-   $buf;
+   sprintf "$l: unused:%d", $self->unused;
 }
 
-#
-# Helpers
-#
-
 1;
 
 __END__
 
 =head1 NAME
 
-Net::Frame::ICMPv4 - Internet Control Message Protocol v4 layer object
+Net::Frame::ICMPv4::TimeExceed - ICMPv4 TimeExceed type object
 
 =head1 SYNOPSIS
 
@@ -330,13 +311,9 @@ Patrice E<lt>GomoRE<gt> Auffret
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright (c) 2004-2006, Patrice E<lt>GomoRE<gt> Auffret
+Copyright (c) 2006, Patrice E<lt>GomoRE<gt> Auffret
 
 You may distribute this module under the terms of the Artistic license.
 See LICENSE.Artistic file in the source distribution archive.
 
-=head1 RELATED MODULES
-
-L<NetPacket>, L<Net::RawIP>, L<Net::RawSock>
-
 =cut
